/**
 * Copyright 2019 the orbs-client-sdk-javascript authors
 * This file is part of the orbs-client-sdk-javascript library in the Orbs project.
 *
 * This source code is licensed under the MIT license found in the LICENSE file in the root directory of this source tree.
 * The above notice should be included in all copies or substantial portions of the software.
 */
import { NetworkType } from "../codec/NetworkType";
import { Argument } from "../codec/Arguments";
import { SendTransactionResponse } from "../codec/OpSendTransaction";
import { RunQueryResponse } from "../codec/OpRunQuery";
import { GetTransactionStatusResponse } from "../codec/OpGetTransactionStatus";
import { GetTransactionReceiptProofResponse } from "../codec/OpGetTransactionReceiptProof";
import { GetBlockResponse } from "../codec/OpGetBlock";
export declare const PROCESSOR_TYPE_NATIVE = 1;
export declare const PROCESSOR_TYPE_JAVASCRIPT = 2;
export declare class Client {
    private endpoint;
    private virtualChainId;
    private networkType;
    constructor(endpoint: string, virtualChainId: number, networkType: NetworkType);
    createTransaction(publicKey: Uint8Array, privateKey: Uint8Array, contractName: string, methodName: string, inputArguments: Argument[]): [Uint8Array, string];
    createDeployTransaction(publicKey: Uint8Array, privateKey: Uint8Array, contractName: string, processorType: number, ...sources: Uint8Array[]): [Uint8Array, string];
    createQuery(publicKey: Uint8Array, contractName: string, methodName: string, inputArguments: Argument[]): Uint8Array;
    protected createGetTransactionStatusPayload(txId: string): Uint8Array;
    protected createGetTransactionReceiptProofPayload(txId: string): Uint8Array;
    protected createGetBlockPayload(blockHeight: bigint): Uint8Array;
    sendTransaction(rawTransaction: Uint8Array): Promise<SendTransactionResponse>;
    sendQuery(rawQuery: Uint8Array): Promise<RunQueryResponse>;
    getTransactionStatus(txId: string): Promise<GetTransactionStatusResponse>;
    getTransactionReceiptProof(txId: string): Promise<GetTransactionReceiptProofResponse>;
    getBlock(blockHeight: bigint): Promise<GetBlockResponse>;
    private sendHttpPost;
}
